@@ -277,6 +277,7 @@ struct nd_opt_hdr {		/* Neighbor discovery option header */
 #define ND_OPT_HOMEAGENT_INFO		8
 #define ND_OPT_ROUTE_INFO		9	/* draft-ietf-ipngwg-router-preference, not officially assigned yet */
 #define ND_OPT_RDNSS			25
+#define ND_OPT_DNSSL			31
 
 struct nd_opt_prefix_info {	/* prefix information */
 	u_int8_t	nd_opt_pi_type;
@@ -308,7 +309,7 @@ struct nd_opt_mtu {		/* MTU option */
 	u_int32_t	nd_opt_mtu_mtu;
 };
 
-struct nd_opt_rdnss {		/* RDNSS RFC 5006 */
+struct nd_opt_rdnss {		/* RDNSS RFC 6106 5.1 */
 	u_int8_t	nd_opt_rdnss_type;
 	u_int8_t	nd_opt_rdnss_len;
 	u_int16_t	nd_opt_rdnss_reserved;
@@ -316,6 +317,14 @@ struct nd_opt_rdnss {		/* RDNSS RFC 5006 */
 	struct in6_addr nd_opt_rdnss_addr[1];	/* variable-length */
 };
 
+struct nd_opt_dnssl {		/* DNSSL RFC 6106 5.2 */
+	u_int8_t  nd_opt_dnssl_type;
+	u_int8_t  nd_opt_dnssl_len;
+	u_int16_t nd_opt_dnssl_reserved;
+	u_int32_t nd_opt_dnssl_lifetime;
+	/* followed by list of DNS search domains, variable-length */
+};
+
 struct nd_opt_advinterval {	/* Advertisement interval option */
 	u_int8_t	nd_opt_adv_type;
 	u_int8_t	nd_opt_adv_len;
