@@ -175,7 +175,7 @@ typedef struct {
 #define LWRES_MAX_ALIASES		16		/* max # of aliases */
 #define LWRES_MAX_ADDRS			64		/* max # of addrs */
 
-struct tok opcode[] = {
+static const struct tok opcode[] = {
 	{ LWRES_OPCODE_NOOP,		"noop", },
 	{ LWRES_OPCODE_GETADDRSBYNAME,	"getaddrsbyname", },
 	{ LWRES_OPCODE_GETNAMEBYADDR,	"getnamebyaddr", },
@@ -184,8 +184,8 @@ struct tok opcode[] = {
 };
 
 /* print-domain.c */
-extern struct tok ns_type2str[];
-extern struct tok ns_class2str[];
+extern const struct tok ns_type2str[];
+extern const struct tok ns_class2str[];
 
 static int lwres_printname(size_t, const char *);
 static int lwres_printnamelen(const char *);
