@@ -4,6 +4,7 @@ mkdir -p NEW
 mkdir -p DIFF
 passed=0
 failed=0
+cat /dev/null > failure-outputs.txt
 
 # first run any specific tests.
 for i in *.sh
@@ -14,10 +15,10 @@ do
   then
       echo $i: passed.
       rm -f DIFF/$i.result
-      passed=$(($passed + 1))
+      passed=`expr $passed + 1`
   else
       echo $i: failed.
-      failed=$(($failed + 1))
+      failed=`expr $failed + 1`
   fi          
 done 
 
@@ -36,12 +37,16 @@ do
   then
       echo $name: passed.
       rm -f DIFF/$output.diff
-      passed=$(($passed + 1))
+      passed=`expr $passed + 1`
       echo $passed >.passed
   else
       echo $name: failed.
-      failed=$(($failed + 1))
+      failed=`expr $failed + 1`
       echo $failed >.failed
+      echo "Failed test: $name" >> failure-outputs.txt
+      echo >> failure-outputs.txt
+      cat DIFF/$output.diff >> failure-outputs.txt
+      echo >> failure-outputs.txt
   fi
 done 
 
@@ -56,6 +61,9 @@ printf "%4u tests failed\n" $failed
 printf "%4u tests passed\n" $passed
 echo
 echo
+cat failure-outputs.txt
+echo
+echo
 exit $failed      
 
 
